Logger object — Kivy v1.0.1-dev documentation

# Logger object

Differents level are available :
  - debug
  - info
  - warning
  - error
  - critical

Examples of usage:

    from kivy.logger import Logger
    Logger.notice('This is a notice')
    Logger.debug('This is a notice')

    try:
        raise Exception('bleh')
    except Exception, e:
        Logger.exception(e)

Logger can be controled in the Kivy configuration.

`kivy.logger.` `Logger`

  Kivy default logger instance

`kivy.logger.` `LoggerHistory`

  Kivy history handler

  alias of `HistoryHandler`